@@ -118,12 +118,12 @@ def extract_read_seq(out_dir,fq1,fq2,gz):
                 tab = '\"\\t\"'
                 newLine = '\"\\n\"'
                 if gz:
-                    bash.write(f'''zcat {fq1} | awk '{{if(NR%4!=0)ORS=" ";else ORS={newLine}}}1' | awk 'NR==FNR{{a[$1]=($1{tab}$2{newLine}$3{newLine}$4{newLine}$5)}}NR>FNR{{gsub(/>/,"@");if(a[$1]!={newLine})print a[$1]}}' - {readNamePath} | grep -v '^$' > {outputPath}/{site}.informativeReads.1.fq;
-zcat {fq2} | awk '{{if(NR%4!=0)ORS=" ";else ORS={newLine}}}1' | awk 'NR==FNR{{a[$1]=($1{tab}$2{newLine}$3{newLine}$4{newLine}$5)}}NR>FNR{{gsub(/>/,"@");if(a[$1]!={newLine})print a[$1]}}' - {readNamePath} | grep -v '^$' > {outputPath}/{site}.informativeReads.2.fq;
+                    bash.write(f'''zcat {fq1} | awk '{{if(NR%4!=0)ORS={tab};else ORS={newLine}}}1' | awk -F {tab} 'NR==FNR{{split($1,b," ");a[b[1]]=($1{newLine}$2{newLine}$3{newLine}$4)}}NR>FNR{{gsub(/>/,"@");if(a[$1]!={newLine})print a[$1]}}' - {readNamePath} | grep -v '^$' > {outputPath}/{site}.informativeReads.1.fq;
+zcat {fq2} | awk '{{if(NR%4!=0)ORS={tab};else ORS={newLine}}}1' | awk -F {tab} 'NR==FNR{{split($1,b," ");a[b[1]]=($1{newLine}$2{newLine}$3{newLine}$4)}}NR>FNR{{gsub(/>/,"@");if(a[$1]!={newLine})print a[$1]}}' - {readNamePath} | grep -v '^$' > {outputPath}/{site}.informativeReads.2.fq;
 ''')
                 else:
-                    bash.write(f'''awk '{{if(NR%4!=0)ORS=" ";else ORS={newLine}}}1' {fq1} | awk 'NR==FNR{{a[$1]=($1{tab}$2{newLine}$3{newLine}$4{newLine}$5)}}NR>FNR{{gsub(/>/,"@");if(a[$1]!={newLine})print a[$1]}}' - {readNamePath} | grep -v '^$' > {outputPath}/{site}.informativeReads.1.fq;
-awk '{{if(NR%4!=0)ORS=" ";else ORS={newLine}}}1' {fq2} | awk 'NR==FNR{{a[$1]=($1{tab}$2{newLine}$3{newLine}$4{newLine}$5)}}NR>FNR{{gsub(/>/,"@");if(a[$1]!={newLine})print a[$1]}}' - {readNamePath} | grep -v '^$' > {outputPath}/{site}.informativeReads.2.fq;
+                    bash.write(f'''awk '{{if(NR%4!=0)ORS={tab};else ORS={newLine}}}1' {fq1} | awk -F {tab} 'NR==FNR{{split($1,b," ");a[b[1]]=($1{newLine}$2{newLine}$3{newLine}$4)}}NR>FNR{{gsub(/>/,"@");if(a[$1]!={newLine})print a[$1]}}' - {readNamePath} | grep -v '^$' > {outputPath}/{site}.informativeReads.1.fq;
+awk '{{if(NR%4!=0)ORS={tab};else ORS={newLine}}}1' {fq2} | awk -F {tab} 'NR==FNR{{split($1,b," ");a[b[1]]=($1{newLine}$2{newLine}$3{newLine}$4)}}NR>FNR{{gsub(/>/,"@");if(a[$1]!={newLine})print a[$1]}}' - {readNamePath} | grep -v '^$' > {outputPath}/{site}.informativeReads.2.fq;
 ''')
         bash.write('echo \'extract informative sequences done\'')
     return f'{out_dir}/extractReadSequence.sh'
